@@ -8,9 +8,9 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
+import aws_cdk.core._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ce", "1.39.0", __name__[0:-6], "aws-ce@1.39.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-ce", "1.43.0", __name__[0:-6], "aws-ce@1.43.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
